@@ -35,7 +35,7 @@
 #' @param lty Character string to control the type of the line at which sounds are played. Line types can either be specified as an integer (0=blank, 1=solid (default), 2=dashed, 3=dotted, 4=dotdash, 5=longdash, 6=twodash) or as one of the character strings "blank", "solid", "dashed", "dotted", "dotdash", "longdash", or "twodash", where "blank" uses 'invisible lines' (i.e., does not draw them).Default is 2.
 #' @param lwd Character string to control the width of the line at which sounds are played. Default is 2.
 #' @param axis.type Character string to control the style of spectrogram axes. Currently there are 3 options:
-#' #' \itemize{
+#'  \itemize{
 #' \item \code{standard}: Both Y and X axes are printed as in the default \code{\link[seewave]{spectro}} view. 
 #' \item \code{minimal}: Single lines are used to denote the range defined by 1 s and 1 kHz for the X and Y axes respectively.
 #' \item \code{none}: No axis is printed (also removes ticks, tick labels, and axis labels).
@@ -70,7 +70,7 @@
 #' 
 #' @author Marcelo Araya-Salas (\email{marcelo.araya@@ucr.ac.cr}) 
 #' @references {
-#' Araya-Salas M. (2020). *dynaSpec: dynamic spectrogram visualizations in R*. R package version 1.0.0.
+#' Araya-Salas M & Wilkins M R. (2020). dynaSpec: dynamic spectrogram visualizations in R. R package version 1.0.0.
 #' }
 
 scrolling_spectro <- function(wave, file.name = "scroll.spectro.mp4", hop.size = 11.6, wl = NULL, ovlp = 70, flim = NULL, pal = seewave::reverse.gray.colors.1, speed = 1, fps = 50, t.display = 1.5, fix.time = TRUE, res = 70, width = 700, height = 400, parallel = 1, pb = TRUE, play = TRUE, loop = 1, lcol = "#07889B99", lty = 2, lwd = 2, axis.type = "standard", buffer = 1, ggspectro = FALSE, lower.spectro = TRUE, height.prop = c(5, 1), derivative = FALSE, osc = FALSE, colwave = "black", colbg = "white", spectro.call = NULL, annotation.call = NULL, ...)
@@ -96,13 +96,13 @@ scrolling_spectro <- function(wave, file.name = "scroll.spectro.mp4", hop.size =
     if (!is.call(spectro.call)) stop("'spectro.call' is not a call")
   
   # hopsize  
-  if (!is.numeric(hop.size) | hop.size < 0) stop("'parallel' must be a positive number") 
+  if (!is.numeric(hop.size) | hop.size < 0) stop("'hop.size' must be a positive number") 
 
   # buffer  
-  if (!is.numeric(buffer) | buffer < 0) stop("'parallel' must be a positive number") 
+  if (!is.numeric(buffer) | buffer < 0) stop("'buffer' must be a positive number") 
 
-  # buffer  
-  if (!is.numeric(loop) | loop < 0) stop("'parallel' must be a positive number") 
+  # loop  
+  if (!is.numeric(loop) | loop < 0) stop("'loop' must be a positive number") 
 
   # error if buffer and loop > 1
   if (buffer > 0 & loop > 1) {
@@ -179,27 +179,28 @@ scrolling_spectro <- function(wave, file.name = "scroll.spectro.mp4", hop.size =
   
   # make vector with name of images
   img_names <- paste0(sprintf(paste0("%0",nchar(frames) + 2, "d"), 1:(frames * loop)), ".temp.img.tiff")
-
   
   if (is.null(flim)) # flim on original wave
     flim <- c(0, wave@samp.rate / 2000)
 
   # reset margins at the end
-  opar <- par
-  on.exit(par(opar), add = TRUE)
+  opar <- graphics::par()
+  on.exit(graphics::par(opar), add = TRUE)
   
   # remove temporary files at the end
   on.exit(try(unlink(c(temp.video, temp.audio, list.files(path = tempdir(), full.names = TRUE, pattern = "\\.temp.img.tiff$"))), silent = TRUE), add = TRUE)
  
   on.exit(try(unlink(c(file.path(path = tempdir(), "temp.full.spectro.png"), file.path(path = tempdir(), "temp.full.oscillo.png"))), silent = TRUE), add = TRUE)
   
+  wdt <- width * seewave::duration(wave_sil) / t.display
+  if (wdt > 32767) wdt <- 32767 
    
   if (!ggspectro){
   # save full spectrogram of wave
-  grDevices::png(filename = file.path(tempdir(), "temp.full.spectro.png"), height = height, width = width * seewave::duration(wave_sil) / t.display, res = res)
+  grDevices::png(filename = file.path(tempdir(), "temp.full.spectro.png"), height = height, width = wdt, res = res)
   
   # set plot margins for spectrogram
-  par(mar = rep(0, 4))
+  graphics::par(mar = rep(0, 4))
   
   # plot spectro
   if (is.null(spectro.call))
@@ -251,7 +252,7 @@ scrolling_spectro <- function(wave, file.name = "scroll.spectro.mp4", hop.size =
   }
     
   # close plot
-  dev.off()
+  grDevices::dev.off()
   
   # spectral derivatives
   if (derivative){
@@ -260,21 +261,21 @@ scrolling_spectro <- function(wave, file.name = "scroll.spectro.mp4", hop.size =
   spc_img <- imager::load.image(file.path(tempdir(), "temp.full.spectro.png"))
   
   # resave with derivatives
-  grDevices::png(filename = file.path(tempdir(), "temp.full.spectro.png"), height = height, width = width * seewave::duration(wave_sil) / t.display, res = res)
+  grDevices::png(filename = file.path(tempdir(), "temp.full.spectro.png"), height = height, width = wdt, res = res)
   
   # remove margins and make background gray
-  par(mar = rep(0, 4), bg = "gray")
+  graphics::par(mar = rep(0, 4), bg = "gray")
   
   # calculate 2 order derivative
   der.im <- imager::deriche(spc_img, sigma = 3, order = 2, axis="y") 
   
   # plot
-  plot(der.im)
+  graphics::plot(der.im)
   
-  dev.off()
+  grDevices::dev.off()
   }
 
-  par( bg = "white")
+  graphics::par( bg = "white")
   
   } else {
   ..level.. <- NA
@@ -286,21 +287,21 @@ scrolling_spectro <- function(wave, file.name = "scroll.spectro.mp4", hop.size =
       ggplot2::scale_y_continuous(expand = c(0, 0), limits = flim) +
       ggplot2::theme(axis.line = ggplot2::element_blank(), axis.text.x = ggplot2::element_blank(), axis.text.y = ggplot2::element_blank(), axis.ticks = ggplot2::element_blank(), axis.title.x = ggplot2::element_blank(), axis.title.y = ggplot2::element_blank(), legend.position = "none"))
 
-    ggplot2::ggsave(plot = ggsp, filename = file.path(tempdir(), "temp.full.spectro.png"), height = height / res, width = (width * seewave::duration(wave_sil) / t.display) / res, units = "in", dpi = res, device = "png", limitsize = FALSE)    
+    ggplot2::ggsave(plot = ggsp, filename = file.path(tempdir(), "temp.full.spectro.png"), height = height / res, width = wdt / res, units = "in", dpi = res, device = "png", limitsize = FALSE)    
   }
   
   # plot oscillogram
   if (osc){
-    grDevices::png(filename = file.path(tempdir(), "temp.full.oscillo.png"), height = height, width = width * seewave::duration(wave_sil) / t.display, res = res)
+    grDevices::png(filename = file.path(tempdir(), "temp.full.oscillo.png"), height = height, width = wdt, res = res)
     
     # set plot margins for spectrogram
-    par(mar = rep(0, 4))
+    graphics::par(mar = rep(0, 4))
     
     # plot spectro
     oscillo_dynaspec_int(wave = wave_sil, f = wave_sil@samp.rate, xaxt = "n", yaxt = "n", colwave = colwave, bg = colbg)
     
     # close plot
-    dev.off()
+    grDevices::dev.off()
   
     # read image
     osc_img <- png::readPNG(source = file.path(tempdir(), "temp.full.oscillo.png"))
@@ -348,8 +349,8 @@ scrolling_spectro <- function(wave, file.name = "scroll.spectro.mp4", hop.size =
     
     # set regular margins
     if (axis.type == "none")
-      par(mar =  rep(0, 4)) else
-    par(mar =  c(4.2, 4.2, 1, 1) + 0.1)
+      graphics::par(mar =  rep(0, 4)) else
+    graphics::par(mar =  c(4.2, 4.2, 1, 1) + 0.1)
     
     # keep original values
     org.flim <- flim
@@ -362,13 +363,13 @@ scrolling_spectro <- function(wave, file.name = "scroll.spectro.mp4", hop.size =
     }
     
     # plot anything at specific time and freq
-    plot(0,0, xlim = if(fix.time) c(0, t.display) else tlim, ylim = flim, xlab = "Time (s)", ylab = "Frequency (kHz)", xaxs = "i", yaxs = "i", bty = "o", yaxt = "n")
+    graphics::plot(0,0, xlim = if(fix.time) c(0, t.display) else tlim, ylim = flim, xlab = "Time (s)", ylab = "Frequency (kHz)", xaxs = "i", yaxs = "i", bty = "o", yaxt = "n")
     
     # get plotting area coordinates
-    plt <- par("plt")
+    plt <- graphics::par("plt")
     
     # get plotting area in original units
-    usr <- par("usr")
+    usr <- graphics::par("usr")
     
     # add spectrogram segment to plot
     grid::grid.raster(spc_img[, img.x.lim[1]:img.x.lim[2], ], x = plt[1], y =  plt[3] + (plt[4] - plt[3]) * height.prop[2] / height.prop[1], height = (plt[4] - plt[3]) * (1 - height.prop[2] / height.prop[1]), width = plt[2] - plt[1], hjust = 0, vjust = 0)
@@ -390,10 +391,10 @@ scrolling_spectro <- function(wave, file.name = "scroll.spectro.mp4", hop.size =
 
     # right gray rectangle
     if (fix.time)
-    graphics::rect(xleft = tlim_low[2] + usr[1], ybottom = flim[1], ytop = flim[1] + (flim[2] - flim[1]) * height.prop[2] / height.prop[1], xright = if(loop > 1 & tlim_low[1] - usr[1] <= 0) usr[2] - (white_window - (tlim_low[2] - usr[1])) else usr[2], col = adjustcolor("gray", 0.42), border = NA) else # different time limits when looping
+    graphics::rect(xleft = tlim_low[2] + usr[1], ybottom = flim[1], ytop = flim[1] + (flim[2] - flim[1]) * height.prop[2] / height.prop[1], xright = if(loop > 1 & tlim_low[1] - usr[1] <= 0) usr[2] - (white_window - (tlim_low[2] - usr[1])) else usr[2], col = grDevices::adjustcolor("gray", 0.42), border = NA) else # different time limits when looping
       graphics::rect(xleft = tlim_low[2] + usr[1], ybottom = flim[1], ytop = flim[1] + (flim[2] - flim[1]) * height.prop[2] / height.prop[1], xright = if(loop > 1 & tlim_low[1] - usr[1] <= 0) {usr[2] - (white_window - (tlim_low[2] - usr[1]))
         + if (tlim_low[1] - usr[1] <= 0) tlim_low[2] + usr[1] + (seewave::duration(wave_sil) - white_window) / 2 else 0 
-      }  else usr[2], col = adjustcolor("gray", 0.42), border = NA)
+      }  else usr[2], col = grDevices::adjustcolor("gray", 0.42), border = NA)
        
     # box in playing area
     graphics::rect(xleft = tlim_low[1] + usr[1], ybottom = flim[1], ytop = flim[1] + (flim[2] - flim[1]) * height.prop[2] / height.prop[1], xright = tlim_low[2] + usr[1], col = "transparent", lwd = 0.4)
@@ -424,7 +425,7 @@ scrolling_spectro <- function(wave, file.name = "scroll.spectro.mp4", hop.size =
       if (is.null(annotation.call$col)) annotation.call$col <- "black"
       
       # overwrite col in call
-      annotation.call$col <- adjustcolor(annotation.call$col, alpha.f = ann_alpha[x])
+      annotation.call$col <- grDevices::adjustcolor(annotation.call$col, alpha.f = ann_alpha[x])
         
       # overwrite label in call
       
@@ -439,7 +440,7 @@ scrolling_spectro <- function(wave, file.name = "scroll.spectro.mp4", hop.size =
     # reprint box
     graphics::box()
   
-    dev.off()
+    grDevices::dev.off()
     
     # if loop > 1 and out of buffer time
     if (loop > 1)
